@@ -1,7 +1,8 @@
 from scc.actions import Action, NoAction
 
-class TestBoolean(object):
-	
+
+class TestBoolean:
+
 	def test_noaction_is_false(self):
 		"""
 		Tests if None can be used as False boolean value.
@@ -9,8 +10,8 @@ class TestBoolean(object):
 		assert not NoAction()
 		if NoAction():
 			raise Exception("NoAction is True :(")
-	
-	
+
+
 	def test_action_is_true(self):
 		"""
 		Tests if random action works as True boolean value.
@@ -20,4 +21,3 @@ class TestBoolean(object):
 		if a:
 			return
 		raise Exception("Action is False :(")
-
